from bluer_ugv.README.swallow.digital.algo import items as algo_items
from bluer_ugv.README.swallow.digital.design import items as design_items

items = (
    [
        {
            "path": "../docs/bluer_swallow/digital",
        }
    ]
    + design_items
    + algo_items
)
