github_kamangir = "https://github.com/kamangir"

algo_docs = f"{github_kamangir}/bluer-algo/blob/main/bluer_algo/docs"

assets = f"{github_kamangir}/assets/raw/main"

assets2 = f"{github_kamangir}/assets2/raw/main"

assets2_bluer_eagle = f"{assets2}/bluer-eagle"
assets2_bluer_fire = f"{assets2}/bluer-fire"
assets2_bluer_robin = f"{assets2}/bluer-robin"
assets2_bluer_swallow = f"{assets2}/bluer-swallow"
assets2_bluer_sparrow = f"{assets2}/bluer-sparrow"
assets2_bluer_ugv = f"{assets2}/bluer-ugv"

# design
bluer_ugv_mechanical_design = f"{github_kamangir}/bluer-ugv-mechanical-design/"

bluer_robin_design = f"{bluer_ugv_mechanical_design}/blob/main/bluer_robin"

bluer_swallow_electrical_design = (
    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow/electrical"
)
bluer_swallow_mechanical_design = (
    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow/mechanical"
)
bluer_swallow_ultrasonic_sensor_design = (
    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow/ultrasonic-sensors"
)

bluer_sparrow_mechanical_design = (
    f"{bluer_ugv_mechanical_design}/blob/main/bluer_sparrow"
)
