from bluer_objects.README.items import ImageItems
from bluer_ugv.README.consts import assets, assets2_bluer_swallow

items = [
    {
        "path": "../docs/bluer_swallow/digital/algo/yolo",
        "items": ImageItems(
            {
                f"{assets2_bluer_swallow}/yolo-debug.png": "",
            }
        ),
    },
    {
        "path": "../docs/bluer_swallow/digital/algo/yolo/train.md",
        "items": ImageItems(
            {
                f"{assets2_bluer_swallow}/yolo-debug-{0}.png": "",
                f"{assets2_bluer_swallow}/yolo-debug-{2}.png": "",
                f"{assets2_bluer_swallow}/yolo-debug-{3}.png": "",
                f"{assets2_bluer_swallow}/yolo-debug-{4}.png": "",
                f"{assets2_bluer_swallow}/yolo-debug-{5}.png": "",
                f"{assets}/swallow-debug-2025-09-16-19-53-19-4yzsp8/swallow-debug-2025-09-16-19-53-19-4yzsp8-2.gif": "",
            }
        ),
    },
]
