import os
from bluer_options.env import load_config, load_env, get_env

load_env(__name__)
load_config(__name__)


BLUER_BEAST_MODEL = get_env("BLUER_BEAST_MODEL")

BLUER_UGV_CAMERA_TRAINING_PERIOD = get_env("BLUER_UGV_CAMERA_TRAINING_PERIOD", 3.0)
BLUER_UGV_CAMERA_ACTION_PERIOD = get_env("BLUER_UGV_CAMERA_ACTION_PERIOD", 1.5)

BLUER_UGV_SWALLOW_STEERING_SETPOINT = get_env("BLUER_UGV_SWALLOW_STEERING_SETPOINT", 50)

BLUER_UGV_MOUSEPAD_ENABLED = get_env("BLUER_UGV_MOUSEPAD_ENABLED", 0)

BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST = get_env(
    "BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST"
)

BLUER_UGV_SWALLOW_NAVIGATION_MODEL = get_env("BLUER_UGV_SWALLOW_NAVIGATION_MODEL", "")

BLUER_UGV_SWALLOW_YOLO_MODEL = get_env("BLUER_UGV_SWALLOW_YOLO_MODEL")

BLUER_UGV_SWALLOW_YOLO_DATASET_LIST = get_env("BLUER_UGV_SWALLOW_YOLO_DATASET_LIST")

BLUER_UGV_ULTRASONIC_SENSOR_TEST_OBJECT = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_TEST_OBJECT"
)
