dict_of_parts = {
    "rpi3bp": "",
    "dc-motor-12-VDC-45W": "type 2, 2 x right + 2 x left",
    "SLA-Battery": "",
    "XL4015": "",
    "BTS7960": "2 x",
    "470-mF": "",
    "Polyfuse": "optional",
    "TVS-diode": "",
    "resistor": "7 x 330-470 Ω + N x 2.2 kΩ + N x 3.3 kΩ",
    "LED": "green + red + yellow + 4 x blue",
    "rpi-camera": "",
    "PCB-single-14x9_5": "2 x",
    "PCB-double-9x7": "2 x",
    "pushbutton": "",
    "wheel": "4 x ",
    "ultrasonic-sensor": "4 x",
    "connector": "8 pairs",
}
