from bluer_objects.README.items import ImageItems

from bluer_ugv.README.consts import assets2_bluer_sparrow

items = ImageItems(
    {
        f"{assets2_bluer_sparrow}/20250722_174115-2.jpg": "",
        f"{assets2_bluer_sparrow}/20250825_190410.jpg": "",
        f"{assets2_bluer_sparrow}/20250825_190439.jpg": "",
        f"{assets2_bluer_sparrow}/20250825_190450.jpg": "",
        f"{assets2_bluer_sparrow}/20250825_190512.jpg": "",
        f"{assets2_bluer_sparrow}/20250830_125608.jpg": "",
        f"{assets2_bluer_sparrow}/20250830_125643.jpg": "",
        f"{assets2_bluer_sparrow}/20250830_132019.jpg": "",
        f"{assets2_bluer_sparrow}/VID-20250830-WA0000~3_1.gif": "",
        f"{assets2_bluer_sparrow}/20250901_105247.jpg": "",
        f"{assets2_bluer_sparrow}/20250905_120625.jpg": "",
        f"{assets2_bluer_sparrow}/VID-20250905-WA0014_1.gif": "./validation/village-1.md",
    }
)
